@@ -26,8 +26,11 @@ def generate_id_for(obj):
 
 def tree(alias, title='', items=None):
     """Dynamically creates and returns a sitetree.
-    `items` - dynamic sitetree items objects created by `item` function.
 
+    :param str|unicode alias:
+    :param str|unicode title:
+    :param iterable items: dynamic sitetree items objects created by `item` function.
+    :rtype: TreeBase
     """
     tree_obj = get_tree_model()(alias=alias, title=title)
     tree_obj.id = generate_id_for(tree_obj)
@@ -52,23 +55,23 @@ def item(title, url, children=None, url_as_pattern=True, hint='', alias='', desc
          access_by_perms=None, perms_mode_all=True, **kwargs):
     """Dynamically creates and returns a sitetree item object.
 
-    :param str title:
-    :param str url:
+    :param str|unicode title:
+    :param str|unicode url:
     :param list, set children: a list of children for tree item. Children should also be created by `item` function.
     :param bool url_as_pattern: consider URL as a name of a named URL
-    :param str hint: hints are usually shown to users
-    :param str alias: item name to address it from templates
-    :param str description: additional information on item (usually is not shown to users)
+    :param str|unicode hint: hints are usually shown to users
+    :param str|unicode alias: item name to address it from templates
+    :param str|unicode description: additional information on item (usually is not shown to users)
     :param bool in_menu: show this item in menus
     :param bool in_breadcrumbs: show this item in breadcrumbs
     :param bool in_sitetree: show this item in sitetrees
     :param bool access_loggedin: show item to logged in users only
     :param bool access_guest: show item to guest users only
-    :param list, str, int, Permission access_by_perms: restrict access to users with these permissions
+    :param list|str||unicode|int, Permission access_by_perms: restrict access to users with these permissions
     :param bool perms_mode_all: permissions set interpretation rule:
                 True - user should have all the permissions;
                 False - user should have any of chosen permissions.
-    :return:
+    :rtype: TreeItemBase
     """
     item_obj = get_tree_item_model()(title=title, url=url, urlaspattern=url_as_pattern,
                                    hint=hint, alias=alias, description=description, inmenu=in_menu,
@@ -120,7 +123,11 @@ def item(title, url, children=None, url_as_pattern=True, hint='', alias='', desc
 
 
 def import_app_sitetree_module(app):
-    """Imports sitetree module from a given app."""
+    """Imports sitetree module from a given app.
+
+    :param str|unicode app: Application name
+    :return: module|None
+    """
     module_name = settings.APP_MODULE_NAME
     module = import_module(app)
     try:
@@ -133,7 +140,11 @@ def import_app_sitetree_module(app):
 
 
 def import_project_sitetree_modules():
-    """Imports sitetrees modules from packages (apps)."""
+    """Imports sitetrees modules from packages (apps).
+    Returns a list of submodules.
+
+    :rtype: list
+    """
     from django.conf import settings as django_settings
     submodules = []
     for app in django_settings.INSTALLED_APPS:
@@ -144,16 +155,25 @@ def import_project_sitetree_modules():
 
 
 def get_app_n_model(settings_entry_name):
-    """Returns tuple with application and tree[item] model class names."""
+    """Returns tuple with application and tree[item] model class names.
+
+    :param str|unicode settings_entry_name:
+    :rtype: tuple
+    """
     try:
         app_name, model_name = getattr(settings, settings_entry_name).split('.')
     except ValueError:
-        raise ImproperlyConfigured('`SITETREE_%s` must have the following format: `app_name.model_name`.' % settings_entry_name)
+        raise ImproperlyConfigured(
+            '`SITETREE_%s` must have the following format: `app_name.model_name`.' % settings_entry_name)
     return app_name, model_name
 
 
 def get_model_class(settings_entry_name):
-    """Returns a certain sitetree model as defined in the project settings."""
+    """Returns a certain sitetree model as defined in the project settings.
+
+    :param str|unicode settings_entry_name:
+    :rtype: TreeItemBase|TreeBase
+    """
     app_name, model_name = get_app_n_model(settings_entry_name)
     if apps_get_model is None:
         model = get_model(app_name, model_name)
@@ -164,16 +184,23 @@ def get_model_class(settings_entry_name):
             model = None
 
     if model is None:
-        raise ImproperlyConfigured('`SITETREE_%s` refers to model `%s` that has not been installed.' % (settings_entry_name, model_name))
+        raise ImproperlyConfigured(
+            '`SITETREE_%s` refers to model `%s` that has not been installed.' % (settings_entry_name, model_name))
 
     return model
 
 
 def get_tree_model():
-    """Returns the Tree model, set for the project."""
+    """Returns the Tree model, set for the project.
+
+    :rtype: TreeBase
+    """
     return get_model_class('MODEL_TREE')
 
 
 def get_tree_item_model():
-    """Returns the TreeItem model, set for the project."""
+    """Returns the TreeItem model, set for the project.
+
+    :rtype: TreeItemBase
+    """
     return get_model_class('MODEL_TREE_ITEM')
